@@ -39,8 +39,8 @@ void MaxTest::max1()
   int r = max(42, 100);
   CPPUNIT_ASSERT( r == 100 );
 
-  r = max(++r, r);
-  CPPUNIT_ASSERT( r == 101 );
+  int t = max(++r, 0);
+  CPPUNIT_ASSERT( t == 101 );
 }
 void MaxTest::max2()
 {
